import { makeStyles } from '@material-ui/core'
import Stack from '@mui/material/Stack';
import Slider from '@mui/material/Slider';
import PlayCircleIcon from '@mui/icons-material/PlayCircle';
import PauseCircleIcon from '@mui/icons-material/PauseCircle';
import VolumeUpIcon from '@mui/icons-material/VolumeUp';
import VolumeOffIcon from '@mui/icons-material/VolumeOff';
import AudioFileIcon from '@mui/icons-material/AudioFile';
import { useEffect } from 'react';

const useStyles = makeStyles({
  container: {
    width: '100%',
    backgroundColor: '#ececec',
    borderRadius: 5,
    padding:'0 5px'
  },
  icon: {
    color: '#2d8fff',
    cursor:"pointer"
  },
  iconCancel: {
    color: '#a3a3a3',
    cursor:"pointer"
  }
})

interface IAudioPlayer {
  src: string,
  audio:any,
  setAudio: any,
  i:number
}

const  AudioPlayer = ({ src,audio,setAudio,i }: IAudioPlayer) => {
  const classes = useStyles()
  const handlePlay = () => {
    if (audio) {
      const oldAudio = audio.audio
      oldAudio.pause()
      oldAudio.currentTime = 0
    }
    const newAudio = new Audio(src)
    const newObject = {
      audio: newAudio,
      i,
      pause: true,
      volume:true
    }
    setAudio(newObject)
    newAudio.play()
  }

  const handlePause = () => {
    if (audio) {
      const oldAudio = audio.audio
      oldAudio.pause()
      oldAudio.currentTime = 0
      setAudio(false)
    }
  }
  
    const handleVolume = () => {
      if (audio) {
        if (audio.volume) {
         audio.audio.volume = 0
         audio.volume = false
      } else {
         audio.audio.volume = 1
         audio.volume = true
      }
    } 
  }

  useEffect(() => {
    if (audio && audio.i !== i &&
      audio.audio.currentTime === audio.audio.duration) {
        setAudio(false)
      }
  }, [audio, i, setAudio])
  
  
  return (
    <div className={classes.container} >
      <Stack spacing={2} direction="row" sx={{ mb: 1 }} alignItems="center">
        {audio.i !== i && <PlayCircleIcon onClick={handlePlay}
          fontSize="large" className={classes.icon} />}
        {!audio && audio.i === i && <PlayCircleIcon onClick={handlePlay}
          fontSize="large" className={classes.icon} />}
        {audio && audio.i === i && audio.pause && <PauseCircleIcon
          onClick={handlePause} fontSize="large" className={classes.iconCancel} />}
           <Slider
            size="small"
            defaultValue={audio.i === i && audio.audio.currentTime}
            max={audio.i === i &&audio.audio.duration?audio.audio.duration:0}
            aria-label="Small"
            valueLabelDisplay="auto"
        />
        {audio.i !== i && <a href={src}  target="_blank" rel="noreferrer">
          <AudioFileIcon style={{ color: '#696969' }} fontSize="large" /> </a>}
        {audio.i === i && audio.volume && <VolumeUpIcon
          onClick={handleVolume} className={classes.icon} fontSize="small"/>}
        {audio.i === i && !audio.volume && <VolumeOffIcon
          onClick={handleVolume} className={classes.iconCancel} fontSize="small"/>}
      </Stack>      
    </div>
  );
}

export default AudioPlayer